# ScheduledExecutor

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![codecov](https://codecov.io/gh/delegacy/scheduledexecutor/branch/main/graph/badge.svg?token=I6VQGPPOKF)](https://codecov.io/gh/delegacy/scheduledexecutor)
